pub struct DogStatsDDebugLogConfiguration { /* private fields */ }Expand description
Configuration for the DogStatsD debug log destination.
Implementations
Sourceimpl DogStatsDDebugLogConfiguration
impl DogStatsDDebugLogConfiguration
Sourcepub fn from_configuration(
config: &GenericConfiguration,
default_log_file_path: PathBuf,
) -> Result<Self, GenericError>
pub fn from_configuration( config: &GenericConfiguration, default_log_file_path: PathBuf, ) -> Result<Self, GenericError>
Creates a new DogStatsDDebugLogConfiguration from the given configuration.
If dogstatsd_log_file is empty, default_log_file_path is used.
Sourcepub const fn enabled(&self) -> bool
pub const fn enabled(&self) -> bool
Returns true if the debug log destination should be added to the topology.
Sourcepub const fn log_file_max_size(&self) -> ByteSize
pub const fn log_file_max_size(&self) -> ByteSize
Returns the maximum size of the active debug log file before rotation.
Sourcepub const fn log_file_max_rolls(&self) -> usize
pub const fn log_file_max_rolls(&self) -> usize
Returns the number of rotated debug log files to keep.